
The main contributors are:

- `Pierre Augier <http://www.legi.grenoble-inp.fr/people/Pierre.Augier/>`_
  (LEGI, CNRS, UGA)

- `Ashwin Vishnu <https://github.com/ashwinvis>`_ (KTH, Stockholm)

with ideas from `Serge Sans Paille <https://github.com/serge-sans-paille/>`_
and `Wolf Vollprecht <https://twitter.com/wuoulf>`_.